@@ -26,8 +26,8 @@ class GRAPHTHEORY_EXPORT ConsoleModule : public QObject
     Q_OBJECT
 
 public:
-    explicit ConsoleModule(QObject *parent = 0);
-    ~ConsoleModule();
+    explicit ConsoleModule(QObject *parent = nullptr);
+    ~ConsoleModule() override;
 
     /**
      * Clear the backlog.
