@@ -13,9 +13,9 @@
 
 class RadialLayoutTest : public QObject
 {
-    Q_OBJECT;
+    Q_OBJECT
 private:
-private slots:
+private Q_SLOTS:
     void emptyGraph();
     void cycleGraph();
     void disconnectedGraph();
